@@ -201,6 +201,22 @@ def test_expect_numpysampler_works(vstate, operator):
     assert isinstance(out, nk.stats.Stats)
 
 
+def test_qutip_conversion(vstate):
+    # skip test if qutip not installed
+    pytest.importorskip("qutip")
+
+    ket = vstate.to_array()
+    q_obj = vstate.to_qobj()
+
+    assert q_obj.type == "ket"
+    assert len(q_obj.dims) == 2
+    assert q_obj.dims[0] == list(vstate.hilbert.shape)
+    assert q_obj.dims[1] == [1 for i in range(vstate.hilbert.size)]
+
+    assert q_obj.shape == (vstate.hilbert.n_states, 1)
+    np.testing.assert_allclose(q_obj.data.todense(), ket.reshape(q_obj.shape))
+
+
 @pytest.mark.parametrize(
     "operator",
     [
